:html_theme.sidebar_secondary.remove: true

.. module:: pyneon

.. include:: ../README.md
   :parser: myst_parser.sphinx_

.. toctree::
   :maxdepth: 2
   :hidden:

   Tutorials <tutorials/index>
   API reference <reference/index>